"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PolicyContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INSTANCE_LABEL_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    DECISIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """policy name"""
    instance_label: builtins.str
    """label identifying the instance of the policy"""
    path: builtins.str
    """policy path aka package name"""
    @property
    def decisions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """list (1..N) of policy decisions (aka rules)"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        instance_label: builtins.str = ...,
        path: builtins.str = ...,
        decisions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["decisions", b"decisions", "instance_label", b"instance_label", "name", b"name", "path", b"path"]) -> None: ...

global___PolicyContext = PolicyContext
