# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aserto/authorizer/v2/api/policy_context.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-aserto/authorizer/v2/api/policy_context.proto\x12\x18\x61serto.authorizer.v2.api\"|\n\rPolicyContext\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0einstance_label\x18\x02 \x01(\tR\rinstanceLabel\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12\x1c\n\tdecisions\x18\x04 \x03(\tR\tdecisionsB\xf8\x01\n\x1c\x63om.aserto.authorizer.v2.apiB\x12PolicyContextProtoP\x01Z@github.com/aserto-dev/go-authorizer/aserto/authorizer/v2/api;api\xa2\x02\x04\x41\x41VA\xaa\x02\x18\x41serto.Authorizer.V2.Api\xca\x02\x18\x41serto\\Authorizer\\V2\\Api\xe2\x02$Aserto\\Authorizer\\V2\\Api\\GPBMetadata\xea\x02\x1b\x41serto::Authorizer::V2::Apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aserto.authorizer.v2.api.policy_context_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.aserto.authorizer.v2.apiB\022PolicyContextProtoP\001Z@github.com/aserto-dev/go-authorizer/aserto/authorizer/v2/api;api\242\002\004AAVA\252\002\030Aserto.Authorizer.V2.Api\312\002\030Aserto\\Authorizer\\V2\\Api\342\002$Aserto\\Authorizer\\V2\\Api\\GPBMetadata\352\002\033Aserto::Authorizer::V2::Api'
  _POLICYCONTEXT._serialized_start=75
  _POLICYCONTEXT._serialized_end=199
# @@protoc_insertion_point(module_scope)
