# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aserto/authorizer/v2/authorizer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from aserto.authorizer.v2.api import identity_context_pb2 as aserto_dot_authorizer_dot_v2_dot_api_dot_identity__context__pb2
from aserto.authorizer.v2.api import policy_context_pb2 as aserto_dot_authorizer_dot_v2_dot_api_dot_policy__context__pb2
from aserto.authorizer.v2.api import module_pb2 as aserto_dot_authorizer_dot_v2_dot_api_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%aserto/authorizer/v2/authorizer.proto\x12\x14\x61serto.authorizer.v2\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a google/protobuf/field_mask.proto\x1a/aserto/authorizer/v2/api/identity_context.proto\x1a-aserto/authorizer/v2/api/policy_context.proto\x1a%aserto/authorizer/v2/api/module.proto\"\r\n\x0bInfoRequest\"x\n\x0cInfoResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x16\n\x06\x63ommit\x18\x02 \x01(\tR\x06\x63ommit\x12\x12\n\x04\x64\x61te\x18\x03 \x01(\tR\x04\x64\x61te\x12\x0e\n\x02os\x18\x04 \x01(\tR\x02os\x12\x12\n\x04\x61rch\x18\x05 \x01(\tR\x04\x61rch\"]\n\x10GetPolicyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"M\n\x11GetPolicyResponse\x12\x38\n\x06result\x18\x01 \x01(\x0b\x32 .aserto.authorizer.v2.api.ModuleR\x06result\"P\n\x13ListPoliciesRequest\x12\x39\n\nfield_mask\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"P\n\x14ListPoliciesResponse\x12\x38\n\x06result\x18\x01 \x03(\x0b\x32 .aserto.authorizer.v2.api.ModuleR\x06result\"\xc4\x02\n\x13\x44\x65\x63isionTreeRequest\x12N\n\x0epolicy_context\x18\x01 \x01(\x0b\x32\'.aserto.authorizer.v2.api.PolicyContextR\rpolicyContext\x12T\n\x10identity_context\x18\x02 \x01(\x0b\x32).aserto.authorizer.v2.api.IdentityContextR\x0fidentityContext\x12\x43\n\x07options\x18\x03 \x01(\x0b\x32).aserto.authorizer.v2.DecisionTreeOptionsR\x07options\x12\x42\n\x10resource_context\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x0fresourceContext\"g\n\x13\x44\x65\x63isionTreeOptions\x12J\n\x0epath_separator\x18\x01 \x01(\x0e\x32#.aserto.authorizer.v2.PathSeparatorR\rpathSeparatorJ\x04\x08\x02\x10\x03\"f\n\x14\x44\x65\x63isionTreeResponse\x12\x1b\n\tpath_root\x18\x01 \x01(\tR\x08pathRoot\x12+\n\x04path\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x04pathJ\x04\x08\x02\x10\x03\"\xf5\x01\n\tIsRequest\x12N\n\x0epolicy_context\x18\x01 \x01(\x0b\x32\'.aserto.authorizer.v2.api.PolicyContextR\rpolicyContext\x12T\n\x10identity_context\x18\x02 \x01(\x0b\x32).aserto.authorizer.v2.api.IdentityContextR\x0fidentityContext\x12\x42\n\x10resource_context\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x0fresourceContext\"6\n\x08\x44\x65\x63ision\x12\x1a\n\x08\x64\x65\x63ision\x18\x01 \x01(\tR\x08\x64\x65\x63ision\x12\x0e\n\x02is\x18\x02 \x01(\x08R\x02is\"J\n\nIsResponse\x12<\n\tdecisions\x18\x01 \x03(\x0b\x32\x1e.aserto.authorizer.v2.DecisionR\tdecisions\"\xa5\x01\n\x0cQueryOptions\x12\x18\n\x07metrics\x18\x01 \x01(\x08R\x07metrics\x12\x1e\n\ninstrument\x18\x02 \x01(\x08R\ninstrument\x12\x36\n\x05trace\x18\x03 \x01(\x0e\x32 .aserto.authorizer.v2.TraceLevelR\x05trace\x12#\n\rtrace_summary\x18\x04 \x01(\x08R\x0ctraceSummary\"\xbf\x03\n\x0cQueryRequest\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12\x14\n\x05input\x18\x02 \x01(\tR\x05input\x12\x41\n\x07options\x18\x03 \x01(\x0b\x32\".aserto.authorizer.v2.QueryOptionsH\x00R\x07options\x88\x01\x01\x12S\n\x0epolicy_context\x18\x04 \x01(\x0b\x32\'.aserto.authorizer.v2.api.PolicyContextH\x01R\rpolicyContext\x88\x01\x01\x12Y\n\x10identity_context\x18\x05 \x01(\x0b\x32).aserto.authorizer.v2.api.IdentityContextH\x02R\x0fidentityContext\x88\x01\x01\x12G\n\x10resource_context\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructH\x03R\x0fresourceContext\x88\x01\x01\x42\n\n\x08_optionsB\x11\n\x0f_policy_contextB\x13\n\x11_identity_contextB\x13\n\x11_resource_context\"\x88\x04\n\x0e\x43ompileRequest\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12\x14\n\x05input\x18\x02 \x01(\tR\x05input\x12\x1a\n\x08unknowns\x18\x03 \x03(\tR\x08unknowns\x12)\n\x10\x64isable_inlining\x18\x04 \x03(\tR\x0f\x64isableInlining\x12\x41\n\x07options\x18\x05 \x01(\x0b\x32\".aserto.authorizer.v2.QueryOptionsH\x00R\x07options\x88\x01\x01\x12S\n\x0epolicy_context\x18\x06 \x01(\x0b\x32\'.aserto.authorizer.v2.api.PolicyContextH\x01R\rpolicyContext\x88\x01\x01\x12Y\n\x10identity_context\x18\x07 \x01(\x0b\x32).aserto.authorizer.v2.api.IdentityContextH\x02R\x0fidentityContext\x88\x01\x01\x12G\n\x10resource_context\x18\x08 \x01(\x0b\x32\x17.google.protobuf.StructH\x03R\x0fresourceContext\x88\x01\x01\x42\n\n\x08_optionsB\x11\n\x0f_policy_contextB\x13\n\x11_identity_contextB\x13\n\x11_resource_context\"\xc9\x01\n\x0f\x43ompileResponse\x12/\n\x06result\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x06result\x12\x31\n\x07metrics\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x07metrics\x12-\n\x05trace\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructR\x05trace\x12#\n\rtrace_summary\x18\x04 \x03(\tR\x0ctraceSummary\"\xcb\x01\n\rQueryResponse\x12\x33\n\x08response\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x08response\x12\x31\n\x07metrics\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x07metrics\x12-\n\x05trace\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructR\x05trace\x12#\n\rtrace_summary\x18\x04 \x03(\tR\x0ctraceSummary*]\n\rPathSeparator\x12\x1a\n\x16PATH_SEPARATOR_UNKNOWN\x10\x00\x12\x16\n\x12PATH_SEPARATOR_DOT\x10\x01\x12\x18\n\x14PATH_SEPARATOR_SLASH\x10\x02*~\n\nTraceLevel\x12\x17\n\x13TRACE_LEVEL_UNKNOWN\x10\x00\x12\x13\n\x0fTRACE_LEVEL_OFF\x10\x01\x12\x14\n\x10TRACE_LEVEL_FULL\x10\x02\x12\x15\n\x11TRACE_LEVEL_NOTES\x10\x03\x12\x15\n\x11TRACE_LEVEL_FAILS\x10\x04\x32\xbc\r\n\nAuthorizer\x12\x91\x02\n\x0c\x44\x65\x63isionTree\x12).aserto.authorizer.v2.DecisionTreeRequest\x1a*.aserto.authorizer.v2.DecisionTreeResponse\"\xa9\x01\x82\xd3\xe4\x93\x02\x1f:\x01*\"\x1a/api/v2/authz/decisiontree\x92\x41\x80\x01\n\nauthorizer\x12\rDecision tree\x1a\x31Returns decision tree for given identity context.*\x18\x61uthorizer.decision_treeb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\x8f\x02\n\x02Is\x12\x1f.aserto.authorizer.v2.IsRequest\x1a .aserto.authorizer.v2.IsResponse\"\xc5\x01\x82\xd3\xe4\x93\x02\x15:\x01*\"\x10/api/v2/authz/is\x92\x41\xa6\x01\n\nauthorizer\x12\x0fIs (authorized)\x1a`Determines if identity context is authorized to access the resource guarded by the given policy.*\rauthorizer.isb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\xf3\x01\n\x05Query\x12\".aserto.authorizer.v2.QueryRequest\x1a#.aserto.authorizer.v2.QueryResponse\"\xa0\x01\x82\xd3\xe4\x93\x02\x18:\x01*\"\x13/api/v2/authz/query\x92\x41\x7f\n\nauthorizer\x12\x12Query (authorized)\x1a\x33\x45xecutes a rego query on the loaded policy runtime.*\x10\x61uthorizer.queryb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\x83\x02\n\x07\x43ompile\x12$.aserto.authorizer.v2.CompileRequest\x1a%.aserto.authorizer.v2.CompileResponse\"\xaa\x01\x82\xd3\xe4\x93\x02\x1a:\x01*\"\x15/api/v2/authz/compile\x92\x41\x86\x01\n\nauthorizer\x12\x14\x43ompile (authorized)\x1a\x36\x45xecutes a partial query on the loaded policy runtime.*\x12\x61uthorizer.compileb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\xf6\x01\n\x0cListPolicies\x12).aserto.authorizer.v2.ListPoliciesRequest\x1a*.aserto.authorizer.v2.ListPoliciesResponse\"\x8e\x01\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v2/policies\x92\x41s\n\nauthorizer\x12\rList Policies\x1a/Lists the policy modules for the policy bundle.*\rpolicies.listb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\xf4\x01\n\tGetPolicy\x12&.aserto.authorizer.v2.GetPolicyRequest\x1a\'.aserto.authorizer.v2.GetPolicyResponse\"\x95\x01\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v2/policies/{id=*/**}\x92\x41p\n\nauthorizer\x12\nGet Policy\x1a\x30Gets the policy modules for the given module Id.*\x0cpolicies.getb\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x12\x9b\x01\n\x04Info\x12!.aserto.authorizer.v2.InfoRequest\x1a\".aserto.authorizer.v2.InfoResponse\"L\x82\xd3\xe4\x93\x02\x0e\x12\x0c/api/v2/info\x92\x41\x35\n\x04Info\x12\x04Info\x1a\x1bReturn version information.*\x08info.getb\x00\x42\xcf\x02\n\x18\x63om.aserto.authorizer.v2B\x0f\x41uthorizerProtoP\x01ZCgithub.com/aserto-dev/go-authorizer/aserto/authorizer/v2;authorizer\xa2\x02\x03\x41\x41X\xaa\x02\x14\x41serto.Authorizer.V2\xca\x02\x14\x41serto\\Authorizer\\V2\xe2\x02 Aserto\\Authorizer\\V2\\GPBMetadata\xea\x02\x16\x41serto::Authorizer::V2\x92\x41j*\x01\x02\x32\x10\x61pplication/json:\x10\x61pplication/jsonZ)\n\'\n\x10\x41uthorizerAPIKey\x12\x13\x08\x02\x1a\rauthorization \x02\x62\x16\n\x14\n\x10\x41uthorizerAPIKey\x12\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aserto.authorizer.v2.authorizer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.aserto.authorizer.v2B\017AuthorizerProtoP\001ZCgithub.com/aserto-dev/go-authorizer/aserto/authorizer/v2;authorizer\242\002\003AAX\252\002\024Aserto.Authorizer.V2\312\002\024Aserto\\Authorizer\\V2\342\002 Aserto\\Authorizer\\V2\\GPBMetadata\352\002\026Aserto::Authorizer::V2\222Aj*\001\0022\020application/json:\020application/jsonZ)\n\'\n\020AuthorizerAPIKey\022\023\010\002\032\rauthorization \002b\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['DecisionTree']._options = None
  _AUTHORIZER.methods_by_name['DecisionTree']._serialized_options = b'\202\323\344\223\002\037:\001*\"\032/api/v2/authz/decisiontree\222A\200\001\n\nauthorizer\022\rDecision tree\0321Returns decision tree for given identity context.*\030authorizer.decision_treeb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['Is']._options = None
  _AUTHORIZER.methods_by_name['Is']._serialized_options = b'\202\323\344\223\002\025:\001*\"\020/api/v2/authz/is\222A\246\001\n\nauthorizer\022\017Is (authorized)\032`Determines if identity context is authorized to access the resource guarded by the given policy.*\rauthorizer.isb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['Query']._options = None
  _AUTHORIZER.methods_by_name['Query']._serialized_options = b'\202\323\344\223\002\030:\001*\"\023/api/v2/authz/query\222A\177\n\nauthorizer\022\022Query (authorized)\0323Executes a rego query on the loaded policy runtime.*\020authorizer.queryb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['Compile']._options = None
  _AUTHORIZER.methods_by_name['Compile']._serialized_options = b'\202\323\344\223\002\032:\001*\"\025/api/v2/authz/compile\222A\206\001\n\nauthorizer\022\024Compile (authorized)\0326Executes a partial query on the loaded policy runtime.*\022authorizer.compileb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['ListPolicies']._options = None
  _AUTHORIZER.methods_by_name['ListPolicies']._serialized_options = b'\202\323\344\223\002\022\022\020/api/v2/policies\222As\n\nauthorizer\022\rList Policies\032/Lists the policy modules for the policy bundle.*\rpolicies.listb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['GetPolicy']._options = None
  _AUTHORIZER.methods_by_name['GetPolicy']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v2/policies/{id=*/**}\222Ap\n\nauthorizer\022\nGet Policy\0320Gets the policy modules for the given module Id.*\014policies.getb\026\n\024\n\020AuthorizerAPIKey\022\000'
  _AUTHORIZER.methods_by_name['Info']._options = None
  _AUTHORIZER.methods_by_name['Info']._serialized_options = b'\202\323\344\223\002\016\022\014/api/v2/info\222A5\n\004Info\022\004Info\032\033Return version information.*\010info.getb\000'
  _PATHSEPARATOR._serialized_start=3282
  _PATHSEPARATOR._serialized_end=3375
  _TRACELEVEL._serialized_start=3377
  _TRACELEVEL._serialized_end=3503
  _INFOREQUEST._serialized_start=340
  _INFOREQUEST._serialized_end=353
  _INFORESPONSE._serialized_start=355
  _INFORESPONSE._serialized_end=475
  _GETPOLICYREQUEST._serialized_start=477
  _GETPOLICYREQUEST._serialized_end=570
  _GETPOLICYRESPONSE._serialized_start=572
  _GETPOLICYRESPONSE._serialized_end=649
  _LISTPOLICIESREQUEST._serialized_start=651
  _LISTPOLICIESREQUEST._serialized_end=731
  _LISTPOLICIESRESPONSE._serialized_start=733
  _LISTPOLICIESRESPONSE._serialized_end=813
  _DECISIONTREEREQUEST._serialized_start=816
  _DECISIONTREEREQUEST._serialized_end=1140
  _DECISIONTREEOPTIONS._serialized_start=1142
  _DECISIONTREEOPTIONS._serialized_end=1245
  _DECISIONTREERESPONSE._serialized_start=1247
  _DECISIONTREERESPONSE._serialized_end=1349
  _ISREQUEST._serialized_start=1352
  _ISREQUEST._serialized_end=1597
  _DECISION._serialized_start=1599
  _DECISION._serialized_end=1653
  _ISRESPONSE._serialized_start=1655
  _ISRESPONSE._serialized_end=1729
  _QUERYOPTIONS._serialized_start=1732
  _QUERYOPTIONS._serialized_end=1897
  _QUERYREQUEST._serialized_start=1900
  _QUERYREQUEST._serialized_end=2347
  _COMPILEREQUEST._serialized_start=2350
  _COMPILEREQUEST._serialized_end=2870
  _COMPILERESPONSE._serialized_start=2873
  _COMPILERESPONSE._serialized_end=3074
  _QUERYRESPONSE._serialized_start=3077
  _QUERYRESPONSE._serialized_end=3280
  _AUTHORIZER._serialized_start=3506
  _AUTHORIZER._serialized_end=5230
# @@protoc_insertion_point(module_scope)
