# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aserto/authorizer/v2/api/decision_logs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from aserto.authorizer.v2.api import policy_context_pb2 as aserto_dot_authorizer_dot_v2_dot_api_dot_policy__context__pb2
from aserto.authorizer.v2.api import identity_context_pb2 as aserto_dot_authorizer_dot_v2_dot_api_dot_identity__context__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,aserto/authorizer/v2/api/decision_logs.proto\x12\x18\x61serto.authorizer.v2.api\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a-aserto/authorizer/v2/api/policy_context.proto\x1a/aserto/authorizer/v2/api/identity_context.proto\"\xbd\x04\n\x08\x44\x65\x63ision\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12:\n\x04user\x18\x04 \x01(\x0b\x32&.aserto.authorizer.v2.api.DecisionUserR\x04user\x12@\n\x06policy\x18\x05 \x01(\x0b\x32(.aserto.authorizer.v2.api.DecisionPolicyR\x06policy\x12L\n\x08outcomes\x18\x06 \x03(\x0b\x32\x30.aserto.authorizer.v2.api.Decision.OutcomesEntryR\x08outcomes\x12\x33\n\x08resource\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructR\x08resource\x12U\n\x0b\x61nnotations\x18\x08 \x03(\x0b\x32\x33.aserto.authorizer.v2.api.Decision.AnnotationsEntryR\x0b\x61nnotations\x1a;\n\rOutcomesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x08R\x05value:\x02\x38\x01\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"y\n\x0c\x44\x65\x63isionUser\x12\x43\n\x07\x63ontext\x18\x01 \x01(\x0b\x32).aserto.authorizer.v2.api.IdentityContextR\x07\x63ontext\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x14\n\x05\x65mail\x18\x03 \x01(\tR\x05\x65mail\"\xf1\x01\n\x0e\x44\x65\x63isionPolicy\x12\x41\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\'.aserto.authorizer.v2.api.PolicyContextR\x07\x63ontext\x12)\n\x10registry_service\x18\x02 \x01(\tR\x0fregistryService\x12%\n\x0eregistry_image\x18\x03 \x01(\tR\rregistryImage\x12!\n\x0cregistry_tag\x18\x04 \x01(\tR\x0bregistryTag\x12\'\n\x0fregistry_digest\x18\x05 \x01(\tR\x0eregistryDigestB\xf7\x01\n\x1c\x63om.aserto.authorizer.v2.apiB\x11\x44\x65\x63isionLogsProtoP\x01Z@github.com/aserto-dev/go-authorizer/aserto/authorizer/v2/api;api\xa2\x02\x04\x41\x41VA\xaa\x02\x18\x41serto.Authorizer.V2.Api\xca\x02\x18\x41serto\\Authorizer\\V2\\Api\xe2\x02$Aserto\\Authorizer\\V2\\Api\\GPBMetadata\xea\x02\x1b\x41serto::Authorizer::V2::Apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aserto.authorizer.v2.api.decision_logs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.aserto.authorizer.v2.apiB\021DecisionLogsProtoP\001Z@github.com/aserto-dev/go-authorizer/aserto/authorizer/v2/api;api\242\002\004AAVA\252\002\030Aserto.Authorizer.V2.Api\312\002\030Aserto\\Authorizer\\V2\\Api\342\002$Aserto\\Authorizer\\V2\\Api\\GPBMetadata\352\002\033Aserto::Authorizer::V2::Api'
  _DECISION_OUTCOMESENTRY._options = None
  _DECISION_OUTCOMESENTRY._serialized_options = b'8\001'
  _DECISION_ANNOTATIONSENTRY._options = None
  _DECISION_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _DECISION._serialized_start=234
  _DECISION._serialized_end=807
  _DECISION_OUTCOMESENTRY._serialized_start=684
  _DECISION_OUTCOMESENTRY._serialized_end=743
  _DECISION_ANNOTATIONSENTRY._serialized_start=745
  _DECISION_ANNOTATIONSENTRY._serialized_end=807
  _DECISIONUSER._serialized_start=809
  _DECISIONUSER._serialized_end=930
  _DECISIONPOLICY._serialized_start=933
  _DECISIONPOLICY._serialized_end=1174
# @@protoc_insertion_point(module_scope)
